<template>
  <!-- form -->
  <validation-observer ref="refForm">
    <b-form>
      <b-row>
        <b-col cols="12">
          <b-form-group
            label="大類名稱"
            label-for="name"
            label-cols-md="4"
          >
            <validation-provider
              #default="{ errors }"
              name="大類名稱"
              rules="required"
            >
              <b-form-input
                id="name"
                v-model="name"
                :state="errors.length > 0 ? false:null"
                placeholder="大類名稱"
              />
              <small class="text-danger">{{ strErrors.name }}</small>
            </validation-provider>
          </b-form-group>
        </b-col>
        <b-col cols="12">
          <b-form-group
            label="大類代碼"
            label-for="code"
            label-cols-md="4"
          >
            <validation-provider
              #default="{ errors }"
              name="大類代碼"
              rules="required"
            >
              <b-form-input
                id="code"
                v-model="code"
                :state="errors.length > 0 ? false:null"
                placeholder="大類代碼 | 兩碼英文＋兩碼數字"
              />
              <small class="text-danger">{{ strErrors.code }}</small>
            </validation-provider>
          </b-form-group>
        </b-col>
        <b-col cols="12">
          <b-button
            variant="primary"
            type="submit"
            @click.prevent="validationForm"
          >
            完成
          </b-button>
        </b-col>
      </b-row>
    </b-form>
  </validation-observer>
</template>

<script>
import BCardCode from '@core/components/b-card-code'
import { ValidationProvider, ValidationObserver } from 'vee-validate'
import {
  BFormInput, BFormGroup, BForm, BRow, BCol, BButton, BCardText,
} from 'bootstrap-vue'
import { required, email } from '@validations'
import store from '@/store'
import router from '@/router'
import { ref, onUnmounted } from '@vue/composition-api'
import productClassMainStoreModule from '../productClassMainStoreModule'

export default {
  components: {
    BCardCode,
    ValidationProvider,
    ValidationObserver,
    BCardText,
    BFormInput,
    BFormGroup,
    BForm,
    BRow,
    BCol,
    BButton,
  },
  setup() {
    const USER_APP_STORE_MODULE_NAME = 'information'

    // Register module
    if (!store.hasModule(USER_APP_STORE_MODULE_NAME)) store.registerModule(USER_APP_STORE_MODULE_NAME, productClassMainStoreModule)

    // UnRegister on leave
    onUnmounted(() => {
      if (store.hasModule(USER_APP_STORE_MODULE_NAME)) store.unregisterModule(USER_APP_STORE_MODULE_NAME)
    })

    const refForm = ref(null)
    const code = ref('')
    const name = ref('')
    const strErrors = ref({
      code: '',
      name: '',
    })

    const validationForm = () => {
      updateProductClassMain()
    }

    const fetchProductClassMain = () => {
      store
        .dispatch('information/fetchProductClassMain', {
          id: router.currentRoute.params.id
        })
        .then(response => {
          code.value = response.data.data.code;
          name.value = response.data.data.name;
        })
    }

    const updateProductClassMain = () => {
      store
        .dispatch('information/updateProductClassMain', {
          id: router.currentRoute.params.id,
          code: code.value,
          name: name.value,
        })
        .then(response => {
          for (var prop in strErrors.value) {
            strErrors.value[prop] = '';
          }
          let result = response.data;
          if (result.message == 'success') {
            router.push({ name: 'information-product-class-main' })
          } else {
            for (var prop in result.data) {
              strErrors.value[prop] = result.data[prop].join(' | ');
            }
          }
        })
    }

    fetchProductClassMain()

    return {
      refForm,
      code,
      name,
      strErrors,
      validationForm,
      fetchProductClassMain,
      updateProductClassMain,
    }
  },
}
</script>
